<?xml version="1.0" encoding="ISO-8859-1" ?>
<!--
# $Id: bigbrother.xsl,v 1.24 2004/03/08 15:00:53 camille Exp $

# Copyright 2001-2003 Camille Bgnis and MandrakeSoft S.A., tous droits rservs

#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# Project         : Mandrake Linux
# Module          : Borges
# File            : bigbrother.xsl
# Author          : Camille Bgnis
# Created On      : Mon May  1 16:25:21 2001
# Copyright       : Camille Bgnis camille@mandrakesoft.com,
#                    MandrakeSoft under the GPL license
#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

This stylesheets takes master-revisions-todos.xml as input and outputs an 
HTML summary table 

-->


<xsl:stylesheet
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  version="1.1"> 

<xsl:param name="reports-path" select="'.'"/>

<xsl:output method="xml" encoding="UTF-8" indent="yes"/>


<xsl:template match="/">

  <xsl:variable name="langs" select="/modules/languages/lang[not(@status='inactive')]"/>

<!--
  <xsl:message>
    ////////////////////////////////////////////////
    lang <xsl:copy-of select="$langs"/>
    ////////////////////////////////////////////////
  </xsl:message>
-->

  <xsl:variable name ="title">
    Detailed report status for <xsl:value-of select="/*[1]/@id"/> Release <xsl:value-of select="//revnumber[1]"/>
  </xsl:variable>

  <html>
    <head>
      <META HTTP-EQUIV="Content-Type" CONTENT="text/html; charset=UTF-8"/>
      <title><xsl:value-of select="$title"/></title>
    </head>
    <body bgcolor="white" text="black" link="red" vlink="brown" alink="black">
      <center>
      <h1><xsl:value-of select="$title"/></h1>
      <font size="-1">
      <table border="1">
        <tr>
          <th>
            Module name
            <br>(Original author)</br>
          </th>
          <th>
            Module title
          </th>
          <xsl:for-each select="$langs">
            <th>
              <xsl:value-of select="text()"/>
            </th>
          </xsl:for-each>
        </tr>
        <xsl:apply-templates select="//module"/>
        <xsl:call-template name="totals"/>
      </table>
      </font>
      </center>
    </body>
  </html>
  
</xsl:template>



<!-- Now fill each line with module name and author, module title, module status for each language -->

<xsl:template match="module">
  <xsl:variable name="module" select="@id"/>
  <xsl:variable name="author" select="revhistory/revision[revremark/text()='write']/authorinitials/text()[not(.='tbn')]"/>

  <xsl:variable name="langs" select="/modules/languages/lang[not(@status='inactive')]"/>

  <tr>
    <th>
      <div role="sequence">
        <xsl:attribute name="lang"><xsl:value-of select="@lang"/></xsl:attribute>
        <xsl:value-of select="$module"/>
      </div>
      <xsl:call-template name="author">
        <xsl:with-param name="initials" select="$author[1]"/>
      </xsl:call-template>
    </th>


    <td>
      <xsl:value-of select="title"/>
      <xsl:text> </xsl:text>
    </td>
    <xsl:choose>
      <!-- Is the original author known?-->
      <xsl:when 
        test="revhistory[revision/@role='2translate']/revision[@role='1time']/authorinitials[not(text()='tbn')]">
        <!-- Is this lang part of the local langs list ?-->
        <xsl:variable name="langslist">
          <xsl:copy-of select="$langs"/>
        </xsl:variable>

        <xsl:apply-templates select="revhistory[contains($langslist,@lang)]"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:for-each select="$langs">
          <td>
            <b><font color="#FF0000">Author?</font></b>
          </td>
        </xsl:for-each>
      </xsl:otherwise>
    </xsl:choose>
  </tr>
</xsl:template>
  

<!-- If the original author is known, fill all language status cells -->

<xsl:template match="revhistory">

  <xsl:variable name="lang" select="@lang"/>
  <xsl:variable name="module" select="../@id"/>
  
  <!-- generate an HTML file per module per language with all info in it -->
  <xsl:call-template name="module-index"/>
  
  <td>
    <xsl:choose>
      <!-- Is this module XML Valid? -->
      <xsl:when test="@conformance='0'">
        <strong><font color="#ff0000">XML NOT VALID</font></strong>
      </xsl:when>
      <!-- Is this module fkd? -->
      <xsl:when test="revision[contains(revremark,'corrupt')]">
        <strong><font color="#990000">INVALID</font></strong>
        <xsl:message>
          <xsl:text>Module: </xsl:text><xsl:value-of select="$module"/><xsl:text> in lang </xsl:text><xsl:value-of select="$lang"/><xsl:text> is invalid!&#10;</xsl:text>
        </xsl:message>
      </xsl:when>

      <xsl:otherwise>
        <!-- Here comes status for each module -->
        <xsl:variable name="todotask" select="revision[@status]"/>

        <xsl:choose>
          <!-- Show different things according to the status of the module -->
          <xsl:when test="$todotask[@status='pending']">
            <a href="{$reports-path}/{$lang}/{$module}-index.html">
              Pending
            </a>
          </xsl:when>
          <xsl:when test="$todotask[@status='active']">
            
            <xsl:attribute name="title">
              <xsl:value-of select="$todotask/authorinitials"/>
            </xsl:attribute>
            <xsl:attribute name="lang"><xsl:value-of select="$lang"/></xsl:attribute>
            <a href="{$reports-path}/{$lang}/{$module}-index.html">
              <b><font color="#3366FF" role="task"><xsl:value-of select="$todotask/revremark"/></font></b>
              <br>
                <xsl:call-template name="author">
                  <xsl:with-param name="initials" select="$todotask/authorinitials"/>
                </xsl:call-template>
              </br>
            </a>
          </xsl:when>
          <xsl:when test="$todotask[@status='pending']">
            <a href="{$reports-path}/{$lang}/{$module}-index.html">
              Pending
            </a>
          </xsl:when>
          <xsl:otherwise>
            <a href="{$reports-path}/{$lang}/{$module}-index.html">
              <b><font color="#006600">OK</font></b>
            </a>
          </xsl:otherwise>
        </xsl:choose>
        
      </xsl:otherwise>
    </xsl:choose>
    
  </td>
</xsl:template>


<xsl:template name="author">
  <xsl:param name="initials" select="tbn"/>
  <xsl:choose>
    <xsl:when test="not($initials = 'tbn')">
      <xsl:variable name="author" select="(//*[@id=$initials])[1]"/>
      <xsl:choose>
        <xsl:when test="$author">
          <xsl:apply-templates select="$author"/>
        </xsl:when>
        <xsl:otherwise>
          <font color="#FF0000">Unknown: <xsl:value-of select="$initials"/></font>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:when>
    <xsl:otherwise>
      <font color="#FF0000">(To be named)</font>
    </xsl:otherwise>
  </xsl:choose>


</xsl:template>


<xsl:template match="author|editor">

  <xsl:text>(</xsl:text>
  <a>
    <xsl:attribute name="href">
      <xsl:text>mailto:</xsl:text>
      <xsl:apply-templates select="affiliation/address/email"/>
    </xsl:attribute>
    <xsl:apply-templates select="firstname"/>
    <xsl:text> </xsl:text>
    <xsl:apply-templates select="surname"/>
  </a>
  <xsl:text>)</xsl:text>

</xsl:template>


<xsl:template name="module-index">
  <xsl:variable name="lang" select="@lang"/>
  <xsl:variable name="module" select="../@id"/>

  <xsl:document href="{$reports-path}/{$lang}/{$module}-index.html">
    <html>
      <head>
        <META HTTP-EQUIV="Content-Type" CONTENT="text/html; charset=iso8859-1"/>
        <title>
          Stats for <xsl:value-of select="$module"/> in <xsl:value-of select="$lang"/>
        </title>
      </head>
      <body>
        <h1>
          Stats for <xsl:value-of select="$module"/> in <xsl:value-of select="$lang"/>
        </h1>
        <table border="1">
          <tr>
            <th>
              Task
            </th>
            <th>
              Finished on
            </th>
            <th>
              Author
            </th>
          </tr>
          <xsl:apply-templates select="revision"/>
        </table>
        <xsl:if test="revision[revremark='synch'][date='YYYY-MM-DD'][../revision[@role='1time'][not(date='YYYY-MM-DD')]]">
          <a href="{$module}.ids.html">Changes in IDs/revisions</a><br/>
          <a href="{$module}.changes.html">Side by side not synched elements</a>
        </xsl:if>

      </body>
    </html>
    
  </xsl:document>

</xsl:template>



<xsl:template match="revision">
  <tr>
    <td>
      <xsl:value-of select="revremark"/>
    </td>
    <td>
      <xsl:choose>
        <xsl:when test="@status='active'">
          In Progress
        </xsl:when>
        <xsl:when test="date='YYYY-MM-DD'">
          Pending
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="date"/>
        </xsl:otherwise>
      </xsl:choose>
    </td>
    <td>
      <xsl:call-template name="author">
        <xsl:with-param name="initials" select="authorinitials"/>
      </xsl:call-template>
    </td>
  </tr>
</xsl:template>

<!-- Calculate percents completed -->

<xsl:template name="totals">
  <tr role="totals">
    <th>Total per language</th>
    <th>Percent completed</th>

    <xsl:variable name="root" select="/"/>

    <xsl:variable name="langs" select="/modules/languages/lang[not(@status='inactive')]"/>
    
    <xsl:for-each select="$langs">

      <xsl:variable name="lang" select="text()"/>


      <th>
        <xsl:attribute name="role">total</xsl:attribute>
        <xsl:attribute name="lang">
          <xsl:value-of select="$lang"/>
        </xsl:attribute>
      </th>
    </xsl:for-each>
  </tr>
  
</xsl:template>


</xsl:stylesheet>
