<?xml version="1.0" encoding="ISO-8859-1" ?>
<!--
# $Id: db2omf.xsl,v 1.1 2003/01/28 07:58:49 camille Exp $

# Copyright 2003 MandrakeSoft S.A., Camille Bgnis, tous droits rservs

#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# Project         : Mandrake Linux
# Module          : Borges
# File            : db2omf.xsl
# Author          : Camille Bgnis
# Created On      : Mon Jan 10 16:25:21 2003
# Copyright       : Camille Bgnis camille@mandrakesoft.com,
#                    MandrakeSoft under the GPL license
#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

This stylesheets extracts all relevant information from a master.top.xml
and associated conf.xml to build the related OMF file
Synopsys (xsltproc)

-stringparam doc Starter db2omf.xsl conf.xml

-->


<xsl:stylesheet
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  version="1.1"> 

<xsl:output method="xml" encoding="ISO-8859-1" indent="yes"
  doctype-public="-//OMF//DTD Scrollkeeper OMF Variant V1.0//EN"
  doctype-system= "http://scrollkeeper.sourceforge.net/dtds/scrollkeeper-omf-1.0/scrollkeeper-omf.dtd"/>

  <xsl:param name="master">master.top.xml</xsl:param>
  <xsl:param name="doc">Manual-Name</xsl:param>
  <xsl:param name="path"/>

  <xsl:variable name="info" select="document($master,.)//*[revhistory][1]"/>

  <xsl:template match="/">
    <omf>
      <xsl:apply-templates select="//manual[@id=$doc]"/>
    </omf>
  </xsl:template>


  <xsl:template match="manual">
    <xsl:for-each select="format">
      <xsl:variable name="url"><xsl:value-of select="$doc"/>.<xsl:value-of select="text()"/>
      <xsl:if test="text()='html'">
        <xsl:text>/index.html</xsl:text>
      </xsl:if>
    </xsl:variable>
      <xsl:variable name="mime">
        <xsl:choose>
          <xsl:when test="text()='pdf'">application/pdf</xsl:when>
          <xsl:when test="text()='html'">text/html</xsl:when>
          <xsl:when test="text()='flat.html'">text/html</xsl:when>
          <xsl:when test="text()='ps'">application/postscript</xsl:when>
          <xsl:when test="text()='dvi'">application/x-dvi</xsl:when>
          <xsl:when test="text()='tex'">application/x-tex</xsl:when>
        </xsl:choose>
      </xsl:variable>
      <xsl:for-each select="../lang">
        <resource>
          <creator>
            <xsl:apply-templates select="$info/author[1]"/>
          </creator>
          <title>
            <xsl:apply-templates select="$info/title[1]"/>
            <xsl:if test="$info/subtitle">
              <xsl:text>: </xsl:text>
              <xsl:apply-templates select="$info/subtitle[1]"/>
            </xsl:if>
          </title>
          <date>
            <xsl:value-of select="$info/pubdate"/>
          </date>
          <xsl:for-each select="/configuration/category">
            <subject>
              <xsl:attribute name="category">
                <xsl:apply-templates select="text()"/>
              </xsl:attribute>
              <!-- Scrollkeeper do not like that :-( -->
              <!--              <xsl:apply-templates select="$info/keywordset"/> -->
            </subject>
          </xsl:for-each>
          <description>
            <xsl:apply-templates select="$info/abstract"/>
          </description>
          <type>
            <xsl:apply-templates select="$info/releaseinfo"/>
          </type>
          <coverage>
            <xsl:attribute name="architecture">
              <xsl:apply-templates select="$info/@arch"/>
            </xsl:attribute>
            <xsl:attribute name="os">
              <xsl:apply-templates select="$info/@os"/>
            </xsl:attribute>
          </coverage>
          <format mime="{$mime}"/>
          <identifier>
            <xsl:attribute name="url">
              <xsl:value-of select="text()"/><xsl:text>/</xsl:text><xsl:value-of select="$url"/>
            </xsl:attribute>
          </identifier>
          <language>
            <xsl:attribute name="code">
              <xsl:value-of select="text()"/>
            </xsl:attribute>
          </language>
          <relation>
            <xsl:attribute name="seriesid">
              <xsl:apply-templates select="/*/@omf.seriesid"/>
            </xsl:attribute>
          </relation>
          <rights>
            <xsl:attribute name="type">
              <xsl:apply-templates select="$info/legalnotice[1]/@conformance"/>
            </xsl:attribute>
            <xsl:attribute name="license">
              <xsl:apply-templates select="$info/legalnotice[1]/@role"/>
            </xsl:attribute>
            <xsl:attribute name="holder">
              <xsl:apply-templates select="$info/copyright/holder"/>
            </xsl:attribute>
          </rights>
        </resource>
      </xsl:for-each>
    </xsl:for-each>
  </xsl:template>
  
  
  <xsl:template match="email">
    <xsl:text>(</xsl:text><xsl:apply-templates/><xsl:text>)</xsl:text>
</xsl:template>

<xsl:template match="keyword">
  <xsl:apply-templates/><xsl:text></xsl:text>
  <xsl:if test="not(position()=last())">, </xsl:if>
</xsl:template>


<!-- unused elements -->
<xsl:template match="exclude">
</xsl:template>
<xsl:template match="stylesheet">
</xsl:template>
</xsl:stylesheet>
  
