<?xml version="1.0" encoding="ISO-8859-1" ?>
<!--
# $Id: report_summary.xsl,v 1.17 2004/03/08 15:00:53 camille Exp $

#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# Project         : Mandrake Linux
# Module          : Borges
# File            : report_summary.xsl
# Author          : Camille Bgnis
# Created On      : Mon May  1 16:25:21 2001
# Copyright       : Camille Bgnis camille@mandrakesoft.com,
#                    MandrakeSoft under the GPL license
#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

This stylesheet takes all manuals reports and makes a global summary
from all those reports with percentage of current work done

-->

<xsl:stylesheet
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  version="1.0"> 

<xsl:param name="reportname">master-report.html</xsl:param>
<xsl:param name="manualdir">../manuals</xsl:param>
<xsl:param name="conffilename">conf.xml</xsl:param>
<xsl:param name="release">1.0</xsl:param>



<xsl:output method="xml" encoding="UTF-8" indent="yes"/>

<xsl:template match="/">
  
  <html> 
  <head>
    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
    <title>Overall Report for <xsl:value-of select="configuration/repository/title"/></title>
    <meta name="generator" content="Borges"/>
  </head>
  <title>Overall Report for 
  <xsl:value-of select="configuration/repository/title"/></title>
  <STYLE TYPE="text/css">
    div.done { font-size: larger; font-weight: bold; text-align: center; }
    div.eta { color: green; font-weight: bold;  }
    div.guidelines { font-size: tiny; }
    div.link { color: red; }
    div.start { font-size: smaller; align: right; font-style: italic;  }
    div.today { font-size: smaller; align: right; font-style: italic;  }
    h1 { align: center }
  </STYLE>
  <body bgcolor="white" text="black" link="red" vlink="brown" alink="black">
  <h1>Overall report for 
  <xsl:value-of select="configuration/repository/title"/>
  </h1>
    <div align="center">
      <table border="2">
        <tr>
          <th>Manual/Language</th>
          <xsl:for-each select="configuration/repository/languages/lang[not(@status='inactive')]">
            <th>
              <xsl:value-of select="text()"/>
            </th>
          </xsl:for-each>
        </tr>
        <xsl:for-each select="configuration/repository/manuals/manual[not(@status='inactive')]">
          <xsl:variable name="manual">
            <xsl:value-of select="text()"/>
          </xsl:variable>

          <xsl:variable name="conf-file"><xsl:value-of select="$manualdir"/>/<xsl:value-of select="$manual"/>/<xsl:value-of select="$conffilename"/></xsl:variable>
          <xsl:variable name="conf" select="document($conf-file,.)"/>

          <xsl:variable name="report">../reports/<xsl:value-of select="$manual"/>/<xsl:value-of select="$reportname"/></xsl:variable>


          <tr class="{$manual}">
            <th>
              <a>
                <xsl:attribute name="href"><xsl:value-of select="$report"/></xsl:attribute>
                <xsl:value-of select="text()"/> (<xsl:value-of select="$release"/>)
              </a>
              <div class="guidelines"><small><a>
              <xsl:attribute name="href"><xsl:value-of select="$manual"/>/master.top.pdf</xsl:attribute>
              Print
            </a> | 
            <a>
              <xsl:attribute name="href"><xsl:value-of select="$manual"/>/master.top.flat.html</xsl:attribute>
              HTML
            </a></small>
          </div>
            </th>
            <xsl:for-each select="/configuration/repository/languages/lang[not(@status='inactive')]">
              <xsl:variable name="lang">
                <xsl:value-of select="text()"/>
              </xsl:variable>

              <!--
              <xsl:message>
                report: <xsl:value-of select="$report"/>
              lang: <xsl:value-of select="$lang"/>
              release: .<xsl:value-of select="$release"/>.
            </xsl:message>
            -->

            <td lang="{$lang}" align="top">
              <xsl:choose>
                <xsl:when test="$conf//document/language[@lang=$lang]">
                  <div class="done"><xsl:value-of select="document($report,.)//th[@lang=$lang]"/> %</div>
                  <div class="start">
                    <xsl:variable name="start">
                      <xsl:value-of select="$conf//language[@lang=$lang]/revision[revnumber[text()=$release]]/date"/>
                    </xsl:variable>
                    <xsl:choose>
                      <xsl:when test="$start=''">N/A</xsl:when>
                      <xsl:when test="$start='YYYY-MM-DD'">N/A</xsl:when>
                      <xsl:otherwise><xsl:value-of select="$start"/></xsl:otherwise>
                    </xsl:choose>
                  </div>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:text>N/A</xsl:text>
                </xsl:otherwise>
              </xsl:choose>
            </td>
            
          </xsl:for-each>
        </tr>
      </xsl:for-each>
    </table>
  </div>
  <p>Click on a manual name for detailed report<br/>Click on a format
below manual name to consult the writers' guidelines</p>
  <p>For each language the following is indicated:
    <table border="1">
      <tr>
        <td>
          <div class="done">Percentage of work done so far %</div>
          <div class="start">Date at which work began</div>
          <div class="eta">Estimated date at which manual may be finished
          (at current rate)</div>
        </td>
      </tr>
    </table>
  </p>
</body>

</html>

</xsl:template>

</xsl:stylesheet>
