<?xml version="1.0" encoding="ISO-8859-1" ?>
<!--
# $Id: todo_tasks.xsl,v 1.14 2004/12/23 09:30:22 camille Exp $

# Copyright 2001 MandrakeSoft S.A., tous droits rservs

#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# Project         : Mandrake Linux
# Module          : Borges
# File            : todo_tasks.xsl
# Author          : Camille Bgnis
# Created On      : Mon Jul 28 16:25:21 2003
# Copyright       : Camille Bgnis camille@mandrakesoft.com,
#                    MandrakeSoft under the GPL license
#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

This stylesheets takes all revision histories
(reports/revhistories.xml) as input and outputs an HTML page listing
all authors with pending tasks. Additionaly, it generates one HTML
page per contributor, with a summary table of all tasks waiting for
completion by contributors for all declared documents for one specific
major release. This page is the entry point for the web frontend.

The mail message for each author is also generated in parallel

-->

<xsl:stylesheet
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  version="1.1"> 

<xsl:param name="conf-file" select="'../conf/repository.xml'"/>
<xsl:param name="authorsconf-file" select="'../conf/authors.xml'"/>
<xsl:param name="release" select="'1.0'"/>
<xsl:param name="url" select="'modules/'"/>
<xsl:param name="output" select="'frontend/'"/>
<xsl:param name="cgi" select="'cgi-bin/web-frontend.cgi'"/>
<!-- Languages not to be taken into account -->
<xsl:param name="exclude" select="''"/>

<!-- This hash contains all todo tasks for all releases -->
<!--
translation
(not(../revision/@role='2translate') and (../../revhistory/revision[not(string(date)='YYYY-MM-DD')][@role='2translate'] ) ) 

original or original unknown
     (../revision/@role='2translate' and ((not(@role='1time') or @role='1time' and ( not(string(authorinitials)='tbn') or not(../../revhistory/revision[not(string(authorinitials)='tbn')]) ) )))

todo?
not(following-sibling::revision) or following-sibling::revision[1][not(string(date)='YYYY-MM-DD')]

-->


<xsl:output method="xml" encoding="UTF-8" indent="yes"/>

<!-- <xsl:key name="tasks" match="revision[string(date)='YYYY-MM-DD'][(not(following-sibling::revision) or following-sibling::revision[1][not(string(date)='YYYY-MM-DD')]) and ((../revision/@role='2translate' and ((not(@role='1time') or @role='1time' and not(string(authorinitials)='tbn') or not(../../revhistory/revision[not(string(authorinitials)='tbn')]) ))) or (not(../revision/@role='2translate') and (../../revhistory//revision[not(string(date)='YYYY-MM-DD')][@role='2translate'] ) )) ]" use="authorinitials"/> -->

<xsl:key name="tasks" match="revision[@status='active']" use="authorinitials"/>

<xsl:template match="/">



  <xsl:variable name="title">
    <xsl:value-of select="document($conf-file,.)//title[1]"/>
    Release <xsl:value-of select="$release"/>
  </xsl:variable>

  <html>
    <head>
      <META HTTP-EQUIV="Content-Type" CONTENT="text/html; charset=UTF-8"/>
      <META HTTP-EQUIV="Expires" CONTENT="Mon, 18 May 1974 18:29:02 GMT"/>
      <title><xsl:value-of select="$title"/></title>
    </head>
    <body bgcolor="white" text="black" link="red" vlink="brown" alink="black">
      <h1><xsl:value-of select="$title"/></h1>


      <p>
        <a>
          <xsl:attribute name="href">/~<xsl:value-of select="$cgi"/>?action=regen</xsl:attribute>
          Regenerate Frontend
        </a>
      </p>
      <table border="1">
        <tr>
          <th>Author</th>
          <th>Tasks</th>
        </tr>

        <!-- reset all authors task list by default -->        
        <xsl:for-each select="document($authorsconf-file,.)/authorgroup/*">

          <xsl:variable name="author">
            <xsl:value-of select="@id"/>                  
          </xsl:variable>
          <xsl:document method="xml" href="{$author}.html">
            
            <html>
              <head>
                <META HTTP-EQUIV="Content-Type" CONTENT="text/html; charset=UTF-8"/>
                <META HTTP-EQUIV="Expires" CONTENT="Mon, 18 May 1974 18:29:02 GMT"/>
                <title>
                  <xsl:call-template name="author">
                    <xsl:with-param name="authorinitials" select="$author"/>
                  </xsl:call-template> Tasks List
                </title>
              </head>
              <body bgcolor="white" text="black" link="red" vlink="brown" alink="black">
                <h1>
                  <xsl:call-template name="author">
                    <xsl:with-param name="authorinitials" select="$author"/>
                  </xsl:call-template> Tasks List
                </h1>
                <h2>Nothing more to do for now.</h2>
              </body>
            </html>
              
              
          </xsl:document>
        </xsl:for-each>
          
        <xsl:message>     
        authors:         <xsl:value-of select="//revhistory[not(contains($exclude,@lang))]/revision[generate-id(.)=generate-id(key('tasks',authorinitials))]"/>
        </xsl:message>

        <!-- for each author having todo tasks -->        
        <xsl:for-each select="//revhistory[not(contains($exclude,@lang))]/revision[generate-id(.)=generate-id(key('tasks',authorinitials))]">
          <xsl:sort select="authorinitials"/>

          <xsl:variable name="author">
            <xsl:value-of select="authorinitials"/>                  
          </xsl:variable>
            
          <tr role="author">
            <td role="author">
              <a>
                <xsl:attribute name="href"><xsl:value-of select="authorinitials"/>.html</xsl:attribute>
                <xsl:call-template name="author">
                  <xsl:with-param name="authorinitials" select="authorinitials"/>
                </xsl:call-template>
              </a>
            </td>
            <td role="tasks"><xsl:value-of select="count(key('tasks',authorinitials))"/></td>
          </tr>
            
          <!-- Output author HTML frontend page -->
          <xsl:document method="xml" href="{$author}.html">
                
            <html>
              <head>
                <META HTTP-EQUIV="Content-Type" CONTENT="text/html; charset=UTF-8"/>
                <META HTTP-EQUIV="Expires" CONTENT="Mon, 18 May 1974 18:29:02 GMT"/>
                <title>
                  <xsl:call-template name="author">
                    <xsl:with-param name="authorinitials" select="$author"/>
                  </xsl:call-template> Tasks List
                    </title>
                  </head>
                  <body bgcolor="white" text="black" link="red" vlink="brown" alink="black">
                    <h1>
                      <xsl:call-template name="author">
                        <xsl:with-param name="authorinitials" select="$author"/>
                      </xsl:call-template> Tasks List</h1>
                    
                    <table border="1">
                      <tr>
                        <th>Task</th>
                        <th>Lang</th>
                        <th>Download</th>
                        <th>Edit</th>
                        <th>Upload</th>
                        <xsl:choose>
                          <xsl:when test="$author='tbn'">
                            <th>Author</th>
                          </xsl:when>
                          <xsl:otherwise>
                            <th>Decline</th>
                          </xsl:otherwise>
                        </xsl:choose>
                      </tr>
                      
                      <xsl:for-each select="key('tasks',authorinitials)">
                        <xsl:sort select="revremark"/>
              
                        <xsl:variable name="revremark" select="revremark"/>
                        <xsl:variable name="language" select="../@lang"/>
                        <xsl:variable name="module" select="../../@id"/>
                        <xsl:variable name="orig_lang" select="//*[@id=$module]/revhistory[revision[@role='2translate']]/@lang"/>

                        <!--

                             <xsl:if test="$module='audio-apps-section' and $language='en'">
                               <xsl:message>
                                 <xsl:value-of select="$language"/>     <xsl:text> </xsl:text>
                                 <xsl:copy-of select="../.."/>   
                                 <xsl:value-of select="$module"/>     <xsl:text>
                               </xsl:text>
                               <xsl:value-of select="not(../../revhistory/revision[not(string(date)='YYYY-MM-DD')][@role='2translate'] )"/>     <xsl:text>
                             </xsl:text>
                           </xsl:message>
                         </xsl:if>
                         -->

                         <tr>
                          <th><xsl:value-of select="$revremark"/></th>
                          <td><xsl:value-of select="$language"/></td>
                          <td>
                            <a>
                              <xsl:attribute name="href">/~<xsl:value-of select="$cgi"/>?action=download&amp;module=<xsl:value-of select="$module"/>&amp;language=<xsl:value-of select="$language"/>&amp;orig_lang=<xsl:value-of select="$orig_lang"/>&amp;author=<xsl:value-of select="$author"/></xsl:attribute>
                              <xsl:value-of select="$module"/>
                            </a>
                          </td>
                          <td>
                            <a>
                              <xsl:attribute name="href">/~<xsl:value-of select="$cgi"/>?action=edit&amp;task=<xsl:value-of select="$revremark"/>&amp;module=<xsl:value-of select="$module"/>&amp;language=<xsl:value-of select="$language"/>&amp;orig_lang=<xsl:value-of select="$orig_lang"/>&amp;author=<xsl:value-of select="$author"/></xsl:attribute>
                              Edit
                            </a>
                          </td>
                          <td>
                            <FORM action="/~{$cgi}" enctype="multipart/form-data" method="post">
                              <INPUT type="file" name="module-file"/>
                              <input type="hidden" name="action" value="check"/>
                              <input type="hidden" name="author" value="{$author}"/>
                              <input type="hidden" name="module" value="{$module}"/>
                              <input type="hidden" name="language" value="{$language}"/>
                              <input type="hidden" name="orig_lang" value="{$orig_lang}"/>
                              <input type="hidden" name="task" value="{$revremark}"/>
                              <INPUT type="submit" value="Send"/>
                            </FORM>
                          </td>
                          <xsl:choose>
                            <xsl:when test="$author='tbn'">
                              <td>
                                <FORM action="/~{$cgi}" enctype="multipart/form-data" method="post">
                                  <INPUT type="submit" value="Attribute task to:"/>
                                  <select name="new-author">
                                    <option value="tbn">Select an Author</option>
                                    <xsl:for-each select="document($authorsconf-file,.)/authorgroup/*">
                                      <option>
                                        <xsl:attribute name="value">
                                          <xsl:value-of select="@id"/>
                                        </xsl:attribute>
                                        <xsl:call-template name="author">
                                          <xsl:with-param name="authorinitials" select="@id"/>
                                        </xsl:call-template>
                                      </option>
                                    </xsl:for-each>
                                  </select>
                                  <input type="hidden" name="action" value="author"/>
                                  <input type="hidden" name="author" value="{$author}"/>
                                  <input type="hidden" name="module" value="{$module}"/>
                                  <input type="hidden" name="language" value="{$language}"/>
                                  <input type="hidden" name="task" value="{$revremark}"/>
                                </FORM>
                              </td>
                            </xsl:when>
                            <xsl:otherwise>
                              <td>
                                <FORM action="/~{$cgi}" enctype="multipart/form-data" method="post">
                                  <input type="hidden" name="action" value="author"/>
                                  <input type="hidden" name="new-author" value="tbn"/>
                                  <input type="hidden" name="author" value="{$author}"/>
                                  <input type="hidden" name="module" value="{$module}"/>
                                  <input type="hidden" name="language" value="{$language}"/>
                                  <input type="hidden" name="task" value="{$revremark}"/>
                                  <INPUT type="submit" value="Sorry I can't do that"/>
                                </FORM>                              
                              </td>
                            </xsl:otherwise>
                          </xsl:choose>
                          
                        </tr>
                        
                      </xsl:for-each>
                      
                      
                    </table>
                  </body>
                </html>
            
            
              </xsl:document>
            
              <!-- Output author tasks email message -->
              
              <xsl:variable name="editor">
                <xsl:value-of select="document($authorsconf-file,.)/authorgroup/editor/@id"/>
              </xsl:variable>
                
              <xsl:variable name="mail">
                <xsl:choose>
                  <!-- If task is not attributed yet, send to project manager -->
                  <xsl:when test="$author='tbn'">
                    <xsl:value-of select="document($authorsconf-file,.)/authorgroup/*[@id=$editor]//email"/>
                  </xsl:when>
                  <xsl:otherwise>
                    <xsl:value-of select="document($authorsconf-file,.)/authorgroup/*[@id=$author]//email"/>
                  </xsl:otherwise>
                </xsl:choose>
              </xsl:variable>

              <xsl:document method="text" href="{$mail}.mail">
                  
                <xsl:if test="$author='tbn'">
                  <xsl:text>
***** Tasks to be attributed *****

</xsl:text>
                </xsl:if>
                <xsl:for-each select="key('tasks',authorinitials)">
                  <xsl:sort select="revremark"/>
                    
                  <xsl:variable name="revremark" select="revremark"/>
                  <xsl:variable name="language" select="../@lang"/>
                  <xsl:variable name="module" select="../../@id"/>
                  <xsl:text></xsl:text>
                  <xsl:value-of select="$revremark"/> of <xsl:value-of select="$module"/> in "<xsl:value-of select="$language"/>";
<xsl:text></xsl:text>
                </xsl:for-each>

              </xsl:document>
              
            
            </xsl:for-each>
      
          </table>
        </body>
      </html>
  
</xsl:template>


<!-- Display author name -->
<xsl:template name="author">
  <xsl:param name="authorinitials"/>

  <xsl:variable name="author" select="document($authorsconf-file,.)/authorgroup/*[@id=$authorinitials]"/>
  <xsl:choose>
    <xsl:when test="$authorinitials='tbn'">
      <xsl:text>To be Named Authors</xsl:text>
    </xsl:when>
    <xsl:otherwise>
      <xsl:for-each select="$author/firstname|$author/othername|$author/surname">
        <xsl:value-of select="."/>
        <xsl:text> </xsl:text>
      </xsl:for-each>
    </xsl:otherwise>
  </xsl:choose>

</xsl:template>



</xsl:stylesheet>
