#! /usr/bin/perl -w
#---------------------------------------------------------------
# Project         : Linux-Mandrake
# Module          : bin
# File            : ETA.pl
# Author          : Camille Bgnis
# Created On      : Sun Nov 25 12:25:21 2001
# Copyright       : Camille Bgnis <camille@mandrakesoft.com>,
#                    MandrakeSoft under the GPL license
#---------------------------------------------------------------
# This script takes a repository's main report as input and 
# calculates an estimation of the ETA for each of the manuals  
#---------------------------------------------------------------



use XML::Twig;
use Date::Manip;

use POSIX;           # only use POSIX style


my $filename= $ARGV[0] || die "Which file to process?";


my $report= new XML::Twig( KeepEncoding => 1,
			   comments => "keep",
			   PrettyPrint => "indented",
			   TwigHandlers => { 'td[@lang]' => \&manual }, 
			   );

$report->parsefile( $filename);


# create div element for inserting current date in XML tree
my $today=&UnixDate("today","%R on %A %E %B %Y");
my $todaydiv= new XML::Twig::Elt('div',"Last updated at ".$today." (GMT)");
$todaydiv->set_att("class","today");
# insert it
$todaydiv->paste( 'last_child', $report->root()->first_child("body"));

$report->flush;   

sub manual
{ my( $report, $manual)= @_;
  if ( $manual->get_xpath('div[@class="done"]',0)) {
      my $done=$manual->get_xpath('div[@class="done"]',0)->text();
      $done=~ s/%//;
      my $eta="";

#  print STDERR "done:.$done.";

      if ( $done != 0 ){
	  my $date=$manual->get_xpath('div[@class="start"]',0)->text();
	  if ( ! ( $date eq 'N/A' ) ){
	      $date=&ParseDate($date);
	      my $today=&ParseDate("today");
	      my $delta=&DateCalc($date,$today);
#       print STDERR "delta: $delta\n";
# days elapsed since project began
	      $delta=&Delta_Format($delta,1,"%dh");
#        print STDERR "days elapsed since project began: $delta\n";
# estimated days for total manual writing
	      my $days=int(100*$delta/$done-$delta);
#        print STDERR "estimated days for total manual writing: $days\n";
	      $eta=&DateCalc("today","+ ".$days." days");
	      $eta=&UnixDate($eta,"%e %b %Y");
	  } else {
	      $eta="N/A";
	  }
      }
      else {
	  $eta="N/A";
      }
  
# create div element for inserting in XML tree
      my $etadiv= new XML::Twig::Elt('div',$eta);
      $etadiv->set_att("class","eta");
# insert it
      $etadiv->paste( 'last_child', $manual);
      
      $report->flush;      
  }
  
}

exit;
