#! /usr/bin/perl -w
#---------------------------------------------------------------
# Project         : Linux-Mandrake
# Module          : bin
# File            : costs.pl
# Author          : Camille Bgnis
# Created On      : Mon Nov 4 2002
# Copyright       : Camille Bgnis <camille@mandrakesoft.com>,
#                    MandrakeSoft under the GPL license
#---------------------------------------------------------------
# synopsis: costs.pl repository.xml costs.xhtml
# This script takes all costs information from all manuals of the
# project and build a summary HTML table.


use XML::LibXML;


my $conf = shift || die "$0: Where are located the configuration files?!\n";
my $file = shift || die "$0: What's the name of the accounting information files?!\n";

# Configuration files
my $authorsconf=$conf."authors.xml";
my $globalconf=$conf."repository.xml";

# tasks relative cost

my $parser=XML::LibXML->new();
$parser->expand_entities(0);
$parser->load_ext_dtd(0);

# Parse conf file
my $tree = $parser->parse_file($globalconf);
my $rootconf = $tree->getDocumentElement;

my @manuals=$rootconf->findnodes('//repository/manuals/manual[not(@status="inactive")]');
my $project=$rootconf->findvalue('//repository/title');

# print $root->findvalue('//manuals/manual');

# build accounting info hash table
my %costs;
my %manualscosts;
my %manualstotal;
my %authorstotal;
# this hash tracks modules billed not to bill them twice
my %modules;
foreach my $manual (@manuals) {
    my $manualfile=$manual->getFirstChild->getData;
# Parse revision file
    $tree = $parser->parse_file("$manualfile/$file");
    my $root = $tree->getDocumentElement;
    $manualscosts{"release"}=$root->findnodes('//h2[1]');
# get authors list
    my @authors=$root->findnodes('//tr[1]/td[@role="author"]/@title');
    foreach my $costline ($root->findnodes('//tr[@role="cost"]')) {
	my $module=$costline->findvalue('td[1]');
	foreach  (@authors) {
	    my $author=$_->getFirstChild->getData;
# do not bill twice
	    if (not($modules{$author.$module})) {
		my $xpath='td[@role="'.$author.'"]';
		my $cost=$costline->findvalue("$xpath");
		$cost = 0 unless ($cost);
#		print STDERR "$manualfile:\t$module\t$author:\t$cost\n";
		$costs{$author}+=$cost;
		$manualscosts{$manualfile.$author}+=$cost;
		$manualstotal{$manualfile}+=$cost;
		$authorstotal{$author}+=$cost;
		$modules{$author.$module}=1;
	    }
	}
    }
}

####################################################



# Create HTML output

my $doc = XML::LibXML::Document->new();
my $html = $doc->createElement('html');
$doc->setDocumentElement($html);
my $body = $doc->createElement('body');
$html->appendChild($body);

my $cell = $doc->createElement('h1');

my $text = XML::LibXML::Text->new($project." (".$manualscosts{"release"}.")");
$cell->appendChild($text);
$body->appendChild($cell);

$cell = $doc->createElement('h2');
$text = XML::LibXML::Text->new("Billing information");
$cell->appendChild($text);
$body->appendChild($cell);

my $table = $doc->createElement('table');
$table->setAttribute('border','1');
$body->appendChild($table);

my $note = $doc->createElement('p');

$text = XML::LibXML::Text->new("Note: latest manuals can show lower
values because modules already counted in first manuals are not summed
up again.");

$note->appendChild($text);
$body->appendChild($note);

my $manualsline = $doc->createElement('tr');
$table->appendChild($manualsline);
$cell = $doc->createElement('th');
$text = XML::LibXML::Text->new("Author");
$cell->appendChild($text);
$manualsline->appendChild($cell);

foreach my $manual (@manuals) {
    my $manualfile=$manual->getFirstChild->getData;
    my $cell = $doc->createElement('th');
    my $text = XML::LibXML::Text->new($manualfile);
    $cell->appendChild($text);
    $manualsline->appendChild($cell);
#    print "$manualfile\n";
    }

$cell = $doc->createElement('th');
$text = XML::LibXML::Text->new("TOTAL");
$cell->appendChild($text);
$manualsline->appendChild($cell);

# Parse authors conf file
$tree = $parser->parse_file($authorsconf);
my $authors = $tree->getDocumentElement;

foreach my $author (sort keys %costs) {
    my $name=$authors->findvalue("//author[\@id=\"$author\"]/firstname")." ".$authors->findvalue("//author[\@id=\"$author\"]/surname");
    
#    print STDERR $author." ".$name.")\n";

    my $authorline = $doc->createElement('tr');
    $table->appendChild($authorline);
    my $cell = $doc->createElement('th');
    my $text = XML::LibXML::Text->new($name);
    $cell->appendChild($text);
    $authorline->appendChild($cell);
    foreach my $manual (@manuals) {
	my $manualfile=$manual->getFirstChild->getData;
	$cell = $doc->createElement('td');
	$cell->setAttribute('align','right');
	my $cost=$manualscosts{$manualfile.$author};
	$cost=0 unless $cost;
	$text = XML::LibXML::Text->new($cost);
	$cell->appendChild($text);
	$authorline->appendChild($cell);
    }
    $cell = $doc->createElement('th');
    $cell->setAttribute('align','right');
    $text = XML::LibXML::Text->new($authorstotal{$author});
    $cell->appendChild($text);
    $authorline->appendChild($cell);
}

# print totals footer
$manualsline = $doc->createElement('tr');
$table->appendChild($manualsline);
$cell = $doc->createElement('th');
$cell->setAttribute('align','right');
$text = XML::LibXML::Text->new("TOTAL");
$cell->appendChild($text);
$manualsline->appendChild($cell);

my $bigtotal=0;
foreach my $manualname (@manuals) {
    my $manualfilename=$manualname->getFirstChild->getData;
    $cell = $doc->createElement('th');
    $cell->setAttribute('align','right');
    $manualstotal{$manualfilename}+=0;
    $text = XML::LibXML::Text->new($manualstotal{$manualfilename});
    $cell->appendChild($text);
    $manualsline->appendChild($cell);
    $bigtotal+=$manualstotal{$manualfilename};
}

$cell = $doc->createElement('th');
$cell->setAttribute('align','right');
$text = XML::LibXML::Text->new("$bigtotal");
$cell->appendChild($text);
$manualsline->appendChild($cell);

print $doc->toString;
