#! /usr/bin/perl -w
#---------------------------------------------------------------
# Project         : Linux-Mandrake
# Module          : bin
# File            : extract_entities.pl
# Author          : Camille Bgnis
# Created On      : 2003-11-13
# Copyright       : Camille Bgnis <camille@mandrakesoft.com>,
#                    MandrakeSoft under the GPL license
#---------------------------------------------------------------
# synopsis: extract_entities.pl source/master.top.xml target/master.top.xml

# This script analyses a master document to be inserted in a Borges
# project. It spots every string in it that must be translated,
# creates entities out of them (on standard output) and replaces those
# strings by the corresponding entities in the master.top.xml file.



use XML::LibXML;

my $top = shift || die "$0: What's the master document to process?!\n";
my $target = shift || die "$0: Where to store the modified the master document?!\n";

# parse the master.top.xml
my $parser=XML::LibXML->new();
$parser->expand_entities(1);
$parser->load_ext_dtd(0);

# Parse module file
# print "TOP: $top\n";
my $tree = $parser->parse_file($top);
my $root = $tree->getDocumentElement;

# find strings that are outside a module element and therefore should be made entities.
my @strings=$root->findnodes('//text()[not(ancestor::*[name()="revhistory"])][not(ancestor::*[@id][@role="module"])]');
#my @strings=$root->findnodes('//text()');

open(OUT, ">-:utf8");
binmode(OUT,":utf8");
my $count=0;
foreach my $node (@strings) {
    my $string= $node->nodeValue();
    if ( $string=~/\w/ ) {
	my $entityname="master-entity-".++$count;
	print OUT "<!ENTITY ".$entityname." \"$string\">\n";
	my $container=$node->parentNode;
	$node->unbindNode();
	$container->appendTextNode("\@entity\@$entityname;");
    }
}
close(OUT);

#set lang attribute
$root->setAttribute("lang","\@entity\@lang;");

# fix entities
my $master= $root->toString(1,1);
$master=~ s/\@entity\@/&/g;

# get some lost elements from source and include them in target
my $header="";
open(MASTER, "< $top") || die "$0: open error: \"$top\" $!\n";
while(<MASTER>){ $header.=$_; };
close(MASTER);
# add entities reference
my $entref='[<!ENTITY % entities SYSTEM "entities"> %entities;]';

# regex is different whether there is entities or not
if ( $header=~ /<!DOCTYPE [^\]]*\]\s*>/ ) {
# entities
    $header=~s/(<!DOCTYPE [^\]]*\]\s*>).*/$1/sg;
} else {
# no entities
    $header=~s/(<!DOCTYPE [^\>]*>).*/$1/sg;
}
$header=~s/(\[.*\])?>$/\n$entref>/s;
$master=$header."\n\n".$master;
$master.="
<!-- This is for PSGML Emacs support -->
<!-- Keep this comment at the end of the file
Local variables:
mode: xml
End:
-->
";

# save master
open(MASTER, "> $target") || die "$0: Write error: \"$target\" $!\n";  
binmode(MASTER,":utf8");
print MASTER $master;
close(MASTER);
