#! /usr/bin/perl -w
#---------------------------------------------------------------
# Project         : Linux-Mandrake
# Module          : bin
# File            : revisions_manager.pl
# Author          : Camille Bgnis
# Created On      : 2003-05-19 
# Copyright       : Camille Bgnis <camille@mandrakesoft.com>,
#                    MandrakeSoft under the GPL license
#---------------------------------------------------------------

# This script either:
# - Adds a new revisions cycle to a module's revision history
# - Change a revision state from todo to done
#   Changing other languages type (from write to translate) 
#   if this module happens to be translated
# - Calculate changes for costs evaluation
# The modified revision history is stored in ".".$module.".revhistory.tmp"


use XML::LibXML;

my $synopsis="   revisions_manager.pl add (original|translation) <release> <2translatetask> <module name>
   revisions_manager.pl change <type> <author> <proportionaltasks> <revisionsfile> <module name>";

my $conf= "../../conf/repository.xml";

my $action = shift || die "$0: What's the action to perform?!\n$synopsis\n";
my $type = shift || die "$0: What's the type of revision?!\n";
# Is this a ToDo?
my $wop= $type;
$type=~ s/\..*//;
$wop=~ s/.*\.//;

my $release=0;
my $author="";
my $totranslate="";
my @proportionals;
my $revisionsfile="";

if ( $action eq "add" ) {
    $release= shift || die "$0: What's the release number?!\n";
    $totranslate = shift || die "$0: Who's the name of the task triggering translation?!\n";
}
else {
    $author = shift || die "$0: Who's the author of this revision?!\n";
    my $proportionals = shift || die "$0: What are the tasks which cost is proportional to changes?!\n";
    @proportionals=split(' ',$proportionals);
    $revisionsfile = shift || die "$0: Where is the master revisions file?!\n";
}

my $module = shift || die "$0: What's the module name?!\n";
my $revfile=".".$module.".revhistory";

# Has initial write task been performed?
my $written=0;

# guess language from dir
chomp(my $lang=`pwd`);
$lang=~ s,.*/(\w*)/?,$1,;

# This flag is used to change only first revision
my $modif=0;

# parse the current revision history
my $parser=XML::LibXML->new();
$parser->expand_entities(0);
$parser->load_ext_dtd(0);

# Parse history file
my $histtree = $parser->parse_file($revfile);
my $history = $histtree->getDocumentElement;


# make needed changes on current revision history
my @revisions=$history->findnodes('revision');

foreach my $revision (@revisions) {
    processrevision($revision);
}


if ( $action eq "add" ) {
# Add a translation flow if this module is actually a translation
    if ( ! $history->find('//revision[@role="2translate"]') && $history->find('revision[@role="1time"]')) {
	$type="translation";
#        print "ok: ".$revision->parent->text()."\n";
    }

# parse the configuration file to extract workflow from it
    my $tree = $parser->parse_file($conf);
    $conf = $tree->getDocumentElement;

# make needed changes on current revision history
    my @revisions=$conf->findnodes("//revisions[\@lang=\"$lang\"]/$type/type");
#    print "find //revisions[\@lang=\"$lang\"]/$type/type";

    foreach my $revision (@revisions) {
	revisiontype($revision);
    }

}

# save changes
$histtree->toFile($revfile.".tmp","0");

### End Of Program ###

# functions

sub revisiontype {
    my $revision= $_[0];
    my $role=$revision->getAttribute('role');
    if ( ! $role ) { $role = "" }
    my $weight=$revision->findvalue('weight');
    if ( ! $weight ) { $weight = 0 }

# do not insert that revision if it's a one time revision already done
# neither if it's first release and this is a second time revision
    if ( ! ((($written == 1) && ($role eq "1time")) || (($written == 0) && ($role eq "2time")))) {
	
	my $name=$revision->findvalue('name');
	my $author=$revision->findvalue("author");
	
#	print "Inserting $name\n";

	my $revElt = $histtree->createElement('revision');

	$revElt->appendTextChild('revnumber',$release);
	$revElt->appendTextChild('date',"YYYY-MM-DD");
	$revElt->appendTextChild('authorinitials',$author);
	$revElt->appendTextChild('revremark',$name);

	if ( $role ) {
	    $revElt->setAttribute('role',$role);
	}
	$revElt->setAttribute('vendor',$weight);

# We calculate now the number of changes this module suffered in its
# whole life till this new release. We also record the number of
# "text" elements the module counts. That will be used later to know
# how many whanges have been made in the module during this new
# release.

#	print "ToTranslate? $name eq $totranslate";

	if ( $name eq $totranslate ) {
	    setContentAccountingAttributes($revElt);
	}

	$history->insertBefore($revElt,$history->firstChild);
    }
}

sub processrevision {
    my $revision= $_[0];
    my $revnumber=$revision->findvalue('revnumber');
    my $revremark=$revision->findvalue('revremark');
    my $date=$revision->findvalue('date');
# suppress the revision if it has same number as the translation ones we want to add

#    print "$revnumber == $release\n";

    if ( $revnumber eq $release ) {
	$revision->unbindNode();
    } else {
# Is this the first revision cycle? and has it been completed?
	if ( $revision->hasAttribute('role') && $revision->getAttribute('role') eq "1time" && $date ne "YYYY-MM-DD" ) {
	    $written=1;
	}
    }

# Are we modifying a status?
    if ( $action eq "change" && $revremark eq $type && $modif == 0) {
# today
	my $today="";
	if ($wop eq 'todo') {
	    $today="YYYY-MM-DD";
	}
	else {
	    my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst)=localtime(time);
	    $year += 1900;
	    $mon += 1;
	    if ( $mon < 10) { $mon= "0".$mon };
	    if ( $mday < 10) { $mday= "0".$mday };
	    $today="$year-$mon-$mday";

	}
	($revision->findnodes("date/text()"))[0]->unbindNode;
	($revision->findnodes("date"))[0]->replaceNode(newtextnode("date",$today));
	
	if ( $author ne "unchanged" ) {
	    ($revision->findnodes("authorinitials/text()"))[0]->unbindNode;
	    ($revision->findnodes("authorinitials"))[0]->replaceNode(newtextnode("authorinitials",$author));
	}
#	print $history->toString(1); exit;

# If this is a proportinal task, add an empty revision attribute to the revision, so that report generator knows it needs to compute changes for that revision

	if (( grep { $_ eq $type } @proportionals )  && ( $wop ne 'todo' )) {
		
	    print "Calculating changes for proportional \"$type\" task.\n";

# parse the module's whole revisions history (all languages)
	    my $histparser=XML::LibXML->new();
	    $histparser->expand_entities(0);
	    $histparser->load_ext_dtd(0);
	    my $histtree = $parser->parse_file($revisionsfile);
	    my $wholehist = $histtree->getDocumentElement;
# parse the module
	    my $modparser=XML::LibXML->new();
	    $modparser->expand_entities(0);
	    $modparser->load_ext_dtd(0);
	    my $modtree = $parser->parse_file($module.".xmla");
	    my $moduleElt = $modtree->getDocumentElement;
# Get previous revisions count
	    my $revisions1= $wholehist->findvalue('(//revision[@role="2translate"])[1]/@revision') || 0;
# sum current revisions count
	    my $revisions2= $moduleElt->findvalue('sum(//*/@revision)') || 0;
# Get previous elements count
	    my $elements1= $wholehist->findvalue('(//revision[@role="2translate"])[1]/@remap') || 0;
# count elements with IDs
	    my $elements2= $moduleElt->findvalue('count(//*[starts-with(@id,"BId-")])') || 1;
# count elements with New IDs
	    my $newelements2= $moduleElt->findvalue('count(//*[starts-with(@id,"BIdNEW-")])') || 0;
#	    print "revisions1=$revisions1\n revisions2=$revisions2\n elements1=$elements1\n elements2=$elements2\n newelements2=$newelements2\n";
# This is clumsy: as far as content is removed from a module, changes calculations gets buggy.
	    my $added=$elements2 - $elements1;
	    $added = -$added/10 unless ( $added > 0 );
	    my $revisions=$revisions2 - $revisions1;
	    $revisions = -$revisions/2 unless ( $revisions > 0 );
	    my $changes=sprintf("%.2f",($newelements2+$revisions+$added) /( $newelements2 +  $elements2));
#	    print "++++++++++++++++++++++++++++++++++++++++++++ Added elements: $added\n";
#	    print "+++++++++++++++++++++++++++++++++++++++++++++++++++ Changes: newelements2+revisions+added / ( newelements2 + elements2) = changes\n";
#	    print "+++++++++++++++++++++++++++++++++++++++++++++++++++ Changes: $newelements2+$revisions+$added /( $newelements2 + $elements2) = $changes\n";
# write in report
	    $revision->setAttribute('revision',$changes);
	  
	}
# If we are passing the first task that triggers translation (aka initial module write),
# attributes tracking changes must be recalculated so that initial translation is not accounted as synch too.
	
	if (( $revision->hasAttribute('remap')) && ($revision->getAttribute('remap') == 0 )) {
	    setContentAccountingAttributes($revision);
	}	

# We want to modify only the first matching revision
	$modif=1;
    }
}

sub setContentAccountingAttributes {
    my ($revElt)=@_;

# parse the module
    my $modparser=XML::LibXML->new();
    $modparser->expand_entities(0);
    $modparser->load_ext_dtd(0);
    my $modtree = $parser->parse_file($module.".xmla");
    my $moduleElt = $modtree->getDocumentElement;
# sum changes
    my $changes= $moduleElt->find('sum(//*/@revision)');
# write in report
    $revElt->setAttribute('revision',$changes);
# count elements with IDs
    my $NbElts= $moduleElt->find('count(//*[starts-with(@id,"BId-")])');
# write in report
    $revElt->setAttribute('remap',$NbElts);
}

sub newtextnode {
    my ($elt,$string)=@_;
    my $cell = $histtree->createElement($elt);
    my $text = XML::LibXML::Text->new($string);
    $cell->appendChild($text);
    return $cell;

}
